# remirepo spec file for php-pecl-hdr-histogram
#
# Copyright (c) 2016-2023 Remi Collet
# License: CC-BY-SA-4.0
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

%{?scl:%scl_package php-pecl-hdr-histogram}

%bcond_without      tests

%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
%global proj_name   hdr_histogram
%global pecl_name   hdrhistogram
%global ini_name    40-%{pecl_name}.ini
%global sources     %{proj_name}-%{version}
%global _configure  ../%{sources}/configure

Summary:       PHP extension wrapper for the C hdrhistogram API
Name:          %{?scl_prefix}php-pecl-hdr-histogram
Version:       0.4.2
Release:       4%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:       MIT
Group:         Development/Languages
URL:           https://pecl.php.net/package/%{proj_name}

Source:        https://pecl.php.net/get/%{sources}.tgz

Patch0:        %{proj_name}-arginfo.patch
Patch1:        %{proj_name}-lib0114.patch

BuildRequires: make
BuildRequires: %{?dtsprefix}gcc
BuildRequires: %{?scl_prefix}php-devel >= 7.0
BuildRequires: %{?scl_prefix}php-pear
BuildRequires: %{?scl_prefix}php-json
# use our specific package
BuildRequires: HdrHistogram_c6php-devel >= 0.11.7

Requires:      %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:      %{?scl_prefix}php(api) = %{php_core_api}

Provides:      %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:      %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:      %{?scl_prefix}php-pecl(%{proj_name})         = %{version}
Provides:      %{?scl_prefix}php-pecl(%{proj_name})%{?_isa} = %{version}


%description
HdrHistogram: A High Dynamic Range Histogram.

A Histogram that supports recording and analyzing sampled data value counts
across a configurable integer value range with configurable value precision
within the range. Value precision is expressed as the number of significant
digits in the value recording, and provides control over value quantization
behavior across the value range and the subsequent value resolution at any
given level.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -c -q

# Remove test file to avoid regsitration
sed -e 's/role="test"/role="src"/' \
    %{?_licensedir:-e '/LICENSE/s/role="doc"/role="src"/' } \
    -i package.xml

cd %{sources}
%patch -P0 -p1 -b .pr13
%patch -P1 -p1 -b .pr15

# Check upstream version (often broken)
extver=$(sed -n '/#define PHP_HDR_HISTOGRAM_VERSION/{s/.* "//;s/".*$//;p}' php_hdrhistogram.h)
if test "x${extver}" != "x%{version}"; then
   : Error: Upstream version is ${extver}, expecting %{version}.
   exit 1
fi
cd ..

cat << 'EOF' | tee %{ini_name}
; Enable %{proj_name} extension module
extension=%{pecl_name}.so
EOF

mkdir NTS ZTS


%build
%{?dtsenable}

cd %{sources}
%{__phpize}

cd ../NTS
%configure \
    --with-libdir=%{_lib} \
    --with-php-config=%{__phpconfig}
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%configure \
    --with-libdir=%{_lib} \
    --with-php-config=%{__ztsphpconfig}
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

make -C NTS install INSTALL_ROOT=%{buildroot}

# Install XML package description
install -Dpm 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

# install config file
install -Dpm644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}
install -Dpm644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
cd %{sources}
for i in $(grep 'role="doc"' ../package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 $i %{buildroot}%{pecl_docdir}/%{proj_name}/$i
done


%check
cd %{sources}
OPT="-n"
[ -f %{php_extdir}/json.so ] && OPT="$OPT -d extension=json.so"

: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="$OPT -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php -q --show-diff
%endif

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite for ZTS extension
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="$OPT -d extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__ztsphp} -n run-tests.php -q --show-diff
%endif
%endif


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{proj_name} >/dev/null || :
fi
%endif


%files
%{?_licensedir:%license %{sources}/LICENSE}
%doc %{pecl_docdir}/%{proj_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Fri Sep  1 2023 Remi Collet <remi@remirepo.net> - 0.4.2-4
- build out of sources tree

* Thu Apr 27 2023 Remi Collet <remi@remirepo.net> - 0.4.2-3
- improved patch for libhdr_histogram 0.11.7

* Tue Mar  1 2022 Remi Collet <remi@remirepo.net> - 0.4.2-2
- add patch for libhdr_histogram 0.11.4

* Wed Dec  9 2020 Remi Collet <remi@remirepo.net> - 0.4.2-1
- update to 0.4.2
- raise dependency on PHP 7
- add patch for PHP 8 (missing arginfo) from
  https://github.com/beberlei/hdrhistogram-php/pull/13

* Wed Dec  9 2020 Remi Collet <remi@remirepo.net> - 0.3.0-14
- build using HdrHistogram_c6php

* Wed Aug 19 2020 Remi Collet <remi@remirepo.net> - 0.3.0-13
- F33 build

* Mon Jun 15 2020 Remi Collet <remi@remirepo.net> - 0.3.0-12
- rebuild with hdrhistogram library 0.10.0

* Tue Feb 18 2020 Remi Collet <remi@remirepo.net> - 0.3.0-11
- rebuild with hdrhistogram library 0.9.13

* Tue Nov 19 2019 Remi Collet <remi@remirepo.net> - 0.3.0-10
- rebuild with hdrhistogram library 0.9.12

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 0.3.0-9
- rebuild for 7.4.0RC1

* Tue Jul 23 2019 Remi Collet <remi@remirepo.net> - 0.3.0-8
- rebuild for 7.4.0beta1

* Mon Jan 21 2019 Remi Collet <remi@remirepo.net> - 0.3.0-7
- rebuild with hdrhistogram library 0.9.8

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 0.3.0-6
- rebuild for 7.3.0beta2 new ABI

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 0.3.0-5
- rebuld for 7.3.0alpha4 new ABI

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 0.3.0-4
- rebuild for PHP 7.2.0beta1 new API

* Thu Dec  1 2016 Remi Collet <remi@fedoraproject.org> - 0.3.0-3
- rebuild with PHP 7.1.0 GA

* Wed Sep 14 2016 Remi Collet <remi@fedoraproject.org> - 0.3.0-2
- rebuild for PHP 7.1 new API version

* Thu Sep 01 2016 Remi Collet <remi@fedoraproject.org> - 0.3.0-1
- Update to 0.3.0

* Mon Jul 18 2016 Remi Collet <remi@fedoraproject.org> - 0.2.0-1
- Update to 0.2.0

* Sat Mar  5 2016 Remi Collet <remi@fedoraproject.org> - 0.1.0-2
- adapt for F24

* Fri Jan  1 2016 Remi Collet <remi@fedoraproject.org> - 0.1.0-1
- initial RPM, version 0.1.0 (beta)
- fix test suite on i386
  open https://github.com/beberlei/hdrhistogram-php/pull/10
- honours --with-libdir option
  open https://github.com/beberlei/hdrhistogram-php/pull/9

